@@ -105,7 +105,7 @@ func SharedResolverSpecs() []resolverTest {
 								solver.Dependency(),
 							},
 						},
-						Constraint: solver.Mandatory(),
+						Constraint: ConstraintSubscriptionExists,
 					},
 					{
 						Installable: &SubscriptionInstallable{
@@ -115,7 +115,7 @@ func SharedResolverSpecs() []resolverTest {
 								solver.Dependency(),
 							},
 						},
-						Constraint: solver.Dependency(),
+						Constraint: ConstraintSubscriptionWithoutCandidates,
 					},
 				},
 			},
@@ -270,12 +270,11 @@ func SharedResolverSpecs() []resolverTest {
 						Installable: &SubscriptionInstallable{
 							identifier: "a",
 							constraints: []solver.Constraint{
-								solver.Mandatory(),
-								solver.Dependency("catsrc/catsrc-namespace/alpha/a.v1"),
-								solver.AtMost(1, "catsrc/catsrc-namespace/alpha/a.v1"),
+								ConstraintSubscriptionExists,
+								PrettyConstraint(solver.Dependency("catsrc/catsrc-namespace/alpha/a.v1"), "subscription to %s requires at least one of catsrc/catsrc-namespace/alpha/a.v1"),
 							},
 						},
-						Constraint: solver.Dependency("catsrc/catsrc-namespace/alpha/a.v1"),
+						Constraint: PrettyConstraint(solver.Dependency("catsrc/catsrc-namespace/alpha/a.v1"), "subscription to %s requires at least one of catsrc/catsrc-namespace/alpha/a.v1"),
 					},
 					{
 						Installable: &BundleInstallable{
@@ -288,12 +287,11 @@ func SharedResolverSpecs() []resolverTest {
 						Installable: &SubscriptionInstallable{
 							identifier: "a",
 							constraints: []solver.Constraint{
-								solver.Mandatory(),
-								solver.Dependency("catsrc/catsrc-namespace/alpha/a.v1"),
-								solver.AtMost(1, "catsrc/catsrc-namespace/alpha/a.v1"),
+								ConstraintSubscriptionExists,
+								PrettyConstraint(solver.Dependency("catsrc/catsrc-namespace/alpha/a.v1"), "subscription to %s requires at least one of catsrc/catsrc-namespace/alpha/a.v1"),
 							},
 						},
-						Constraint: solver.Mandatory(),
+						Constraint: ConstraintSubscriptionExists,
 					},
 				}),
 			},
